@@ -11,8 +11,8 @@ from qrunner.core.browser.driver import BrowserDriver
 from qrunner.core.browser.element import WebElement
 from qrunner.core.api.request import HttpRequest, ResponseResult
 import jmespath
-from jsonschema import validate
-from jsonschema.exceptions import ValidationError
+# from jsonschema import validate
+# from jsonschema.exceptions import ValidationError
 
 
 class TestCase(HttpRequest):
@@ -166,17 +166,17 @@ class TestCase(HttpRequest):
         assert ResponseResult.status_code == status_code, \
             f'status_code {ResponseResult} != {status_code}'
 
-    def assertSchema(self, schema):
-        """
-        Assert JSON Schema
-        doc: https://json-schema.org/
-        """
-        try:
-            validate(instance=ResponseResult.response, schema=schema)
-        except ValidationError as msg:
-            assert "Response data" == "Schema data", msg
-        else:
-            assert True
+    # def assertSchema(self, schema):
+    #     """
+    #     Assert JSON Schema
+    #     doc: https://json-schema.org/
+    #     """
+    #     try:
+    #         validate(instance=ResponseResult.response, schema=schema)
+    #     except ValidationError as msg:
+    #         assert "Response data" == "Schema data", msg
+    #     else:
+    #         assert True
 
     # def assertJSON(self, assert_json):
     #     """
